Credits
-------

Development Lead
~~~~~~~~~~~~~~~~

* Mike Waters - https://github.com/mikewaters
* Miroslav Shubernetskiy - https://github.com/miki725

Contributors
~~~~~~~~~~~~

* Khaled Porlin - https://github.com/porlin72
* Agam Dua - https://github.com/agamdua
* Marc Marta - https://github.com/mmarta
* ClairePhila - https://github.com/ClairePhila
